@@ -151,7 +151,7 @@ class Sonnen:
             self._ic_status = self._latest_details_data[self.IC_STATUS]
             return True
         except Exception as error:
-            self._log_error('Error occurred while data parsing')
+            self._log_error(f'Error occurred while data parsing latest details:{error}')
             return False
 
     async def async_fetch_status(self) -> bool:
@@ -162,7 +162,7 @@ class Sonnen:
             )
             return True
         except Exception as error:
-            self._log_error('Error occurred while data parsing')
+            self._log_error(f'Error occurred while data parsing status:{error}')
             return False
 
     async def async_fetch_battery_status(self) -> bool:
@@ -172,8 +172,8 @@ class Sonnen:
                 self.battery_api_endpoint
             )
             return True
-        except Exception as err:
-            self._log_error(f'Error ocurred while data parsing')
+        except Exception as error:
+            self._log_error(f'Error occurred while data parsing battery status:{error}')
         return False
 
     async def async_update(self) -> bool:
